HostExecCommand

Enum HostExecCommand 

pub enum HostExecCommand {
Show 18 variants Cat, Head, Tail, Grep, Rg, Ls, Tree, Wc, Uniq, Diff, Stat, File, Du, Df, Pwd, Hostname, Uptime, Whoami,
}
Closed allowlist of host commands admitted by canonical Synapse execution.

Variants



Cat

Concatenate files.



Head

Read the beginning of files.



Tail

Read the end of files.



Grep

Search text with grep.



Rg

Search text with ripgrep.



Ls

List filesystem entries.



Tree

Render a directory tree.



Wc

Count bytes, words, or lines.



Uniq

Collapse adjacent duplicate lines.



Diff

Compare files.



Stat

Read filesystem metadata.



File

Identify file types.



Du

Summarize filesystem usage.



Df

Report filesystem capacity.



Pwd

Print the working directory.



Hostname

Print the host name.



Uptime

Print host uptime.



Whoami

Print the effective user.

Implementations

Source

impl HostExecCommand

pub fn parse(value: &str) -> InfraResult<Self>

Parses one canonical command name.

pub const fn as_str(self) -> &'static str

Returns the executable name.