InfraError

Enum InfraError 

#[non_exhaustive]
pub enum InfraError { Fleet(FleetError), InvalidRequest { domain: &'static str, message: String, }, UnsupportedTarget { domain: &'static str, host: HostId, }, CommandFailed { domain: &'static str, host: HostId, exit_code: Option<i32>, stderr: String, }, Parse { domain: &'static str, message: String, }, Filesystem { operation: &'static str, path: PathBuf, message: String, }, PathOutsideRoots(PathBuf), Docker(String), }
Product-neutral infrastructure operation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Fleet(FleetError)

Fleet transport or topology failed.



InvalidRequest

A typed request violated a closed contract.

Fields

domain: &'static str

Infrastructure domain.

message: String

Corrective detail.



UnsupportedTarget

The target transport cannot execute the requested driver.

Fields

domain: &'static str

Infrastructure domain.

host: HostId

Target host.



CommandFailed

A bounded command returned a non-zero status.

Fields

domain: &'static str

Infrastructure domain.

host: HostId

Target host.

exit_code: Option<i32>

Process exit status when available.

stderr: String

Bounded stderr text.



Parse

Driver output could not be parsed into the neutral contract.

Fields

domain: &'static str

Infrastructure domain.

message: String

Parse detail.



Filesystem

Descriptor-confined filesystem access failed.

Fields

operation: &'static str

Read operation.

path: PathBuf

Requested path.

message: String

Failure detail.



PathOutsideRoots(PathBuf)

Requested path was not within an admitted read root.



Docker(String)

Docker API access failed.