pub struct CommandFilesystemQueryInspector<E> { /* private fields */ }Expand description
Descriptor-walking filesystem query driver backed by fleet command execution.
Implementations
Sourceimpl<E> CommandFilesystemQueryInspector<E>
impl<E> CommandFilesystemQueryInspector<E>
Sourcepub fn new(executor: Arc<E>, policy: FileReadPolicy) -> Self
pub fn new(executor: Arc<E>, policy: FileReadPolicy) -> Self
Creates a query inspector from an executor and explicit read policy.
Sourcepub fn policy(&self) -> &FileReadPolicy
pub fn policy(&self) -> &FileReadPolicy
Returns the active read policy.