pub struct HostExecPolicy { /* private fields */ }Expand description
Explicit read roots used by the typed host command launcher.
Implementations
Sourceimpl HostExecPolicy
impl HostExecPolicy
Sourcepub fn new<I, P>(roots: I) -> InfraResult<Self>
pub fn new<I, P>(roots: I) -> InfraResult<Self>
Creates a host command policy with one to thirty-two absolute roots.