pub trait FilesystemInspector: Send + Sync {
// Required methods
fn stat<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileMetadata>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn read<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FilePreview>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileHash>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
}Expand description
Product-neutral filesystem inspection engine.
Required Methods
Sourcefn stat<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileMetadata>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn stat<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileMetadata>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Returns metadata for one admitted path.
Sourcefn read<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FilePreview>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn read<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FilePreview>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Reads a bounded prefix of one admitted regular file.
Sourcefn hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileHash>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
host: &'life1 HostRecord,
path: &'life2 Path,
cancellation: &'life3 CancellationToken,
) -> Pin<Box<dyn Future<Output = InfraResult<FileHash>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Hashes one admitted regular file within the policy size limit.